@@ -7,31 +7,36 @@ everything out to disk.
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
-__version__ = "1.0"
+__version__ = "1.1"
+
+import __builtin__
+import os
+import shutil
+from tempfile import NamedTemporaryFile
 
 try:
     import simplejson as json
 except ImportError:
     import json
 
-import os
-import shutil
-from tempfile import NamedTemporaryFile
-
-_open = open  # gets overwritten later
-
 
 class JSONStore(dict):
 
-    def __init__(self, path):
+    def __init__(self, path, json_kw=None):
+        """Create a JSONStore object backed by the file at `path`.
+
+        If a dict is passed in as `json_kw`, it will be used as keyword
+        arguments to the json module.
+        """
         self.path = path
+        self.json_kw = json_kw or {}
 
         if not os.path.exists(path):
             self.sync()  # write empty dict to disk
             return
 
         # load the whole store
-        with _open(path, 'r') as fp:
+        with __builtin__.open(path, 'r') as fp:
             self.update(json.load(fp))
 
     def _mktemp(self):
@@ -39,17 +44,22 @@ class JSONStore(dict):
         dirname = os.path.dirname(self.path)
         return NamedTemporaryFile(prefix=prefix, dir=dirname, delete=False)
 
-    def sync(self):
-        """Atomically write the entire store to disk."""
+    def sync(self, json_kw=None):
+        """Atomically write the entire store to disk.
+
+        If a dict is passed in as `json_kw`, it will be used as keyword
+        arguments to the json module.
+        """
         fp = None
+        json_kw = json_kw or self.json_kw
         try:
             with self._mktemp() as fp:
-                json.dump(self, fp)
+                json.dump(self, fp, **json_kw)
             shutil.copyfile(fp.name, self.path)
         finally:
             if fp:
                 os.remove(fp.name)
 
 
-def open(path):
-    return JSONStore(path)
+def open(path, json_kw=None):
+    return JSONStore(path, json_kw)
